@@ -805,6 +805,7 @@ labelptr gettextsize(float **floatptr)
 /* Generate the popup dialog for getting text scale.		*/ 
 /*--------------------------------------------------------------*/
 
+/* Xt */
 void gettsize(xcWidget button, caddr_t nulldata, caddr_t calldata)
 {
    char buffer[50];
@@ -1400,9 +1401,15 @@ void highlightexcl(xcWidget widget, int func, int value)
 
 #ifndef TCL_WRAPPER
 
-void toggle(xcWidget w, Boolean *boolvalue, caddr_t calldata)
+void toggle(xcWidget w, pointertype soffset, Boolean *setdata)
 {
    Arg	wargs[1];
+   Boolean *boolvalue;
+
+   if (soffset == -1)
+      boolvalue = setdata;
+   else
+      boolvalue = (Boolean *)(areawin + soffset);
 
    *boolvalue = !(*boolvalue);
    XtSetArg(wargs[0], XtNsetMark, *boolvalue);
@@ -1457,8 +1464,10 @@ void setcolorscheme(Boolean boolvalue)
 
 #ifndef TCL_WRAPPER
 
-void inversecolor(xcWidget w, Boolean *boolvalue, caddr_t calldata)
+void inversecolor(xcWidget w, pointertype soffset, caddr_t calldata)
 {
+   Boolean *boolvalue = (Boolean *)(areawin + soffset);
+
    /* change color scheme */
 
    setcolorscheme(*boolvalue);
@@ -1466,7 +1475,7 @@ void inversecolor(xcWidget w, Boolean *boolvalue, caddr_t calldata)
    /* toggle checkmark in menu on "Alt colors" */
 
    if (w == NULL) w = OptionsAltColorsButton;
-   if (w != NULL) toggle(w, boolvalue, calldata);
+   if (w != NULL) toggle(w, soffset, calldata);
    if (eventmode == NORMAL_MODE)
       XDefineCursor (dpy, areawin->window, DEFAULTCURSOR);
 }
@@ -2573,7 +2582,7 @@ void dojustifybit(xcWidget w, labelptr settext, short bitfield)
 	 boolval = (settext->justify & bitfield) ? 0 : 1;
       else
 	 boolval = (areawin->justify & bitfield) ? 0 : 1;
-      toggle(w, &boolval, NULL);
+      toggle(w, (pointertype)(-1), &boolval);
    }
 #endif
 }
@@ -2597,7 +2606,7 @@ void dopinjustbit(xcWidget w, labelptr settext, short bitfield)
 #ifndef TCL_WRAPPER
       if (w != NULL) {
 	 Boolean boolval = (settext->justify & bitfield) ? 0 : 1;
-	 toggle(w, &boolval, NULL);
+	 toggle(w, (pointertype)(-1), &boolval);
       }
 #endif
    }
