@@ -1320,7 +1320,7 @@ typedef struct {
    short	editpart, editsubpart;
    char		*lastbackground;
    Cursor	*defaultcursor;
-} XCWindowData;
+} XCWindowData, *XCWindowDataPtr;
 
 /* Record for undo function */ 
 
